==> aliyun_python_sdk_polardb-1.8.13-py2.py3-none-any.whl: aliyunsdkpolardb/request/v20170801/ModifyMaskingRulesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkpolardb.endpoint import endpoint_data

class ModifyMaskingRulesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'ModifyMaskingRules','polardb')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_DBClusterId(self):
		return self.get_query_params().get('DBClusterId')

	def set_DBClusterId(self,DBClusterId):
		self.add_query_param('DBClusterId',DBClusterId)

	def get_RuleName(self):
		return self.get_query_params().get('RuleName')

	def set_RuleName(self,RuleName):
		self.add_query_param('RuleName',RuleName)

	def get_RuleConfig(self):
		return self.get_query_params().get('RuleConfig')

	def set_RuleConfig(self,RuleConfig):
		self.add_query_param('RuleConfig',RuleConfig)

	def get_Enable(self):
		return self.get_query_params().get('Enable')

	def set_Enable(self,Enable):
		self.add_query_param('Enable',Enable)

	def get_RuleNameList(self):
		return self.get_query_params().get('RuleNameList')

	def set_RuleNameList(self,RuleNameList):
		self.add_query_param('RuleNameList',RuleNameList)

==> aliyun_python_sdk_polardb-1.8.52-py2.py3-none-any.whl: aliyunsdkpolardb/request/v20170801/ModifyMaskingRulesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkpolardb.endpoint import endpoint_data

class ModifyMaskingRulesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'polardb', '2017-08-01', 'ModifyMaskingRules','polardb')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_DBClusterId(self): # String
		return self.get_query_params().get('DBClusterId')

	def set_DBClusterId(self, DBClusterId):  # String
		self.add_query_param('DBClusterId', DBClusterId)
	def get_RuleName(self): # String
		return self.get_query_params().get('RuleName')

	def set_RuleName(self, RuleName):  # String
		self.add_query_param('RuleName', RuleName)
	def get_RuleVersion(self): # String
		return self.get_query_params().get('RuleVersion')

	def set_RuleVersion(self, RuleVersion):  # String
		self.add_query_param('RuleVersion', RuleVersion)
	def get_RuleConfig(self): # String
		return self.get_query_params().get('RuleConfig')

	def set_RuleConfig(self, RuleConfig):  # String
		self.add_query_param('RuleConfig', RuleConfig)
	def get_Enable(self): # String
		return self.get_query_params().get('Enable')

	def set_Enable(self, Enable):  # String
		self.add_query_param('Enable', Enable)
	def get_RuleNameList(self): # String
		return self.get_query_params().get('RuleNameList')

	def set_RuleNameList(self, RuleNameList):  # String
		self.add_query_param('RuleNameList', RuleNameList)
